#[repr(transparent)]pub struct Window {
inner: TypedObjectRef<Window, <Window as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
The main window.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Window, <Window as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Window
impl Window
Sourcepub fn compact(&self) -> <Cell<bool> as Property>::Value
pub fn compact(&self) -> <Cell<bool> as Property>::Value
Whether the window should be in compact view.
It means that the horizontal size is not large enough to hold all the content.
Sourcepub fn set_compact<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_compact<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the window should be in compact view.
It means that the horizontal size is not large enough to hold all the content.
Sourcepub fn session_selection(&self) -> <FixedSelection as Property>::Value
pub fn session_selection(&self) -> <FixedSelection as Property>::Value
The selection of the logged-in sessions.
The one that is selected being the one that is visible.
Sourcepub fn connect_compact_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_compact_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the compact property
Sourcepub fn connect_session_selection_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_selection_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session-selection property
Sourcepub fn notify_compact(&self)
pub fn notify_compact(&self)
Notify listeners of a change in the compact property
Sourcepub fn notify_session_selection(&self)
pub fn notify_session_selection(&self)
Notify listeners of a change in the session-selection property
Sourceimpl Window
impl Window
pub fn new(app: &Application) -> Self
Sourcepub(crate) fn add_session(&self, session: Session)
pub(crate) fn add_session(&self, session: Session)
Add the given session to the session list and select it.
Sourcepub(crate) fn current_session_id(&self) -> Option<String>
pub(crate) fn current_session_id(&self) -> Option<String>
The ID of the currently visible session, if any.
Sourcepub(crate) fn account_switcher(&self) -> &AccountSwitcherPopover
pub(crate) fn account_switcher(&self) -> &AccountSwitcherPopover
The account switcher popover.
Sourcepub(crate) fn session_view(&self) -> &SessionView
pub(crate) fn session_view(&self) -> &SessionView
The SessionView of this window.
Sourcepub(crate) fn show_secret_error(&self, message: &str)
pub(crate) fn show_secret_error(&self, message: &str)
Open the error page and display the given secret error message.
Sourcepub(crate) async fn ask_session(&self) -> Option<String>
pub(crate) async fn ask_session(&self) -> Option<String>
Ask the user to choose a session.
The session list must be ready.
Returns the ID of the selected session, if any.
Sourcepub(crate) fn process_session_intent(
&self,
session_id: &str,
intent: SessionIntent,
)
pub(crate) fn process_session_intent( &self, session_id: &str, intent: SessionIntent, )
Process the given session intent.
The session must be ready.